ipecharts.option.visualmapitems package
=======================================

Submodules
----------

ipecharts.option.visualmapitems.continuous module
-------------------------------------------------

.. automodule:: ipecharts.option.visualmapitems.continuous
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.visualmapitems.piecewise module
------------------------------------------------

.. automodule:: ipecharts.option.visualmapitems.piecewise
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ipecharts.option.visualmapitems
   :members:
   :undoc-members:
   :show-inheritance:
